@@ -1,65 +1,64 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="nl">
+<!DOCTYPE TS><TS version="1.1" language="nl">
 <context>
     <name>ConfigWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="597"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="598"/>
         <source>Keep backlight on</source>
         <translation type="unfinished">Beeld niet dimmen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="599"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="600"/>
         <source>Wakeup screen on alarm</source>
         <translation type="unfinished">Scherm aan bij alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="600"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="601"/>
         <source>Vibrate on alarm</source>
         <translation type="unfinished">Tril bij alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="601"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="602"/>
         <source>Sound on alarm</source>
         <translation type="unfinished">Geluid bij alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="602"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="603"/>
         <source>Alarm banner</source>
         <translation type="unfinished">Alarm tekst</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="623"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="624"/>
         <source>Done</source>
         <translation type="unfinished">Opslaan</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="635"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="636"/>
         <source>Alarm volume: </source>
         <translation type="unfinished">Alarm volume:</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="649"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="650"/>
         <source>Alarm volume: max</source>
         <translation type="unfinished">Alarm volume: max</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="638"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="639"/>
         <source>Alarm muted</source>
         <translation type="unfinished">Stil alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="679"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="680"/>
         <source>Configuration is successfully saved</source>
         <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="684"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="685"/>
         <source>Could NOT save Configuration!</source>
         <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="583"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="584"/>
         <source>Configuration cooktimer</source>
         <translation type="unfinished">Configuratie cooktimer</translation>
     </message>
@@ -67,7 +66,7 @@
 <context>
     <name>DishPickDialog</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2969"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3181"/>
         <source>[Choose dish]</source>
         <translation type="unfinished">[Kies gerecht]</translation>
     </message>
@@ -75,52 +74,52 @@
 <context>
     <name>FormWidget</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2178"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2609"/>
         <source>timer 2 ready!</source>
         <translation type="unfinished">timer 2 klaar!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2276"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2721"/>
         <source>Start</source>
         <translation type="unfinished">Start</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1428"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2081"/>
         <source>Choose dish</source>
         <translation type="unfinished">Kies gerecht</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2091"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2506"/>
         <source>timer 1 ready!</source>
         <translation type="unfinished">timer 1 klaar!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2265"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2710"/>
         <source>timer 3 ready!</source>
         <translation type="unfinished">timer 3 klaar!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2015"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="2416"/>
         <source>Stop</source>
         <translation type="unfinished">Stop</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1741"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1780"/>
         <source>Stopwatch mode ON</source>
         <translation type="unfinished">Stopwatch mode AAN</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1789"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1806"/>
         <source>Stopwatch mode OFF</source>
         <translation type="unfinished">Stopwatch mode UIT</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1564"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1574"/>
         <source>Continue mode ON</source>
         <translation type="unfinished">Vervolg mode AAN</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1569"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1579"/>
         <source>Continue mode OFF</source>
         <translation type="unfinished">Vervolg mode UIT</translation>
     </message>
@@ -158,17 +157,12 @@
         <translation type="unfinished">Door op de tijdsbalk te drukken waarbij het alarm afgaat, zal het alarmsignaal stoppen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="557"/>
-        <source>Long-pressing a timepicker will switch to stopwatch mode</source>
-        <translation type="unfinished">Het lang indrukken van de tijd selector zal de stopwatch mode aanzetten</translation>
-    </message>
-    <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="558"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="559"/>
         <source>Long-pressing a timer bar will (de)activate continue mode</source>
         <translation type="unfinished">Het lang indrukken van de tijdsbalk zal de &quot;vervolg-mode&quot; (de)activeren</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="559"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="560"/>
         <source>By pushing the add icon in the &quot;edit dishes&quot; menu you can set interim messages and make it preload at startup</source>
         <translation type="unfinished">Via het plus icoon in &quot;Bewerk gerechten&quot; kan men tussentijdse berichten zetten en automatisch met het gerecht opstarten</translation>
     </message>
@@ -177,6 +171,16 @@
         <source>Cooktimer provides three timers for preparing the perfect meal.</source>
         <translation type="unfinished">Cooktimer biedt drie timers om een perfecte maaltijd te bereiden.</translation>
     </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="557"/>
+        <source>Long-pressing a dishpicker will reset all dish settings</source>
+        <translation type="unfinished">Het lang indrukken van de gerechtknop zal alle gerechtinstellingen resetten</translation>
+    </message>
+    <message>
+        <location filename="src/opt/cooktimer/cooktimer" line="558"/>
+        <source>Long-pressing a timepicker will switch between countdown and stopwatch</source>
+        <translation type="unfinished">Het lang indrukken van de tijdkiesknop zal wisselen tussen aftellen en stopwatch</translation>
+    </message>
 </context>
 <context>
     <name>MyMainWindow</name>
@@ -244,12 +248,12 @@
 <context>
     <name>TimePickDialog</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2822"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3034"/>
         <source>Done</source>
         <translation type="unfinished">Opslaan</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="2821"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3033"/>
         <source>| hours | minutes | seconds |</source>
         <translation type="unfinished">| uren | minuten | seconden |</translation>
     </message>
@@ -257,42 +261,42 @@
 <context>
     <name>extItemWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="3069"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3281"/>
         <source>Message</source>
         <translation type="unfinished">Bericht</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="3075"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3287"/>
         <source>time</source>
         <translation type="unfinished">tijd</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="3113"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3325"/>
         <source>Done</source>
         <translation type="unfinished">Opslaan</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="3060"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3272"/>
         <source>set on start</source>
         <translation type="unfinished">bij opstarten</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="3108"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3320"/>
         <source>Alarm</source>
         <translation type="unfinished">Alarm</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="3215"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3427"/>
         <source>Message time larger then alarm time!</source>
         <translation type="unfinished">Bericht na alarmtijd!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="3276"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3488"/>
         <source>Max of 3 presets already used!</source>
         <translation type="unfinished">Max van 3 presets al gebruikt!</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="3292"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="3504"/>
         <source>Messages are successfully saved</source>
         <translation type="unfinished">Berichten succesvol opgeslagen</translation>
     </message>
@@ -300,17 +304,17 @@
 <context>
     <name>fileWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="981"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="982"/>
         <source>Choose soundfile</source>
         <translation type="unfinished">Kies geluidsfragment</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1108"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1109"/>
         <source>Configuration is successfully saved</source>
         <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="1113"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="1114"/>
         <source>Could NOT save Configuration!</source>
         <translation type="unfinished">Configuratie kon niet worden opgeslagen!</translation>
     </message>
@@ -318,27 +322,27 @@
 <context>
     <name>itemWindow</name>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="768"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="769"/>
         <source>Dish cooktimes</source>
         <translation type="unfinished">Gerecht kooktijden</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="796"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="797"/>
         <source>Done</source>
         <translation type="unfinished">Opslaan</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="797"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="798"/>
         <source>New</source>
         <translation type="unfinished">Nieuw</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="945"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="946"/>
         <source>time</source>
         <translation type="unfinished">tijd</translation>
     </message>
     <message>
-        <location filename="src/opt/cooktimer/cooktimer" line="936"/>
+        <location filename="src/opt/cooktimer/cooktimer" line="937"/>
         <source>Configuration is successfully saved</source>
         <translation type="unfinished">Configuratie is succesvol opgeslagen</translation>
     </message>
